@@ -276,10 +276,11 @@ class ObjectStorageSFTPServer(ForkingTCPServer, paramiko.ServerInterface):
     allow_reuse_address = True
 
     def __init__(self, address, host_key=None, authurl=None, max_children=20, keystone=None,
-            no_scp=False, split_size=0, hide_part_dir=False, auth_timeout=None, negotiation_timeout=0):
+            no_scp=False, split_size=0, hide_part_dir=False, auth_timeout=None,
+            negotiation_timeout=0, insecure=False):
         self.log = paramiko.util.get_logger("paramiko")
         self.log.debug("%s: start server" % self.__class__.__name__)
-        self.fs = ObjectStorageFS(None, None, authurl=authurl, keystone=keystone, hide_part_dir=hide_part_dir) # unauthorized
+        self.fs = ObjectStorageFS(None, None, authurl=authurl, keystone=keystone, hide_part_dir=hide_part_dir, insecure=insecure) # unauthorized
         self.host_key = host_key
         self.max_children = max_children
         self.no_scp = no_scp
